const assert = require('assert');
const { When, Then } = require('@cucumber/cucumber');

const { fixtures } = require('../../fixtures/server');

const mockValidConfig = fixtures.get('config-valid');

const xMessageResponse = function(xMessages) {
  const message = fixtures.get('message-vehicle-status');
  let response = [];
  for (let i=0; i<xMessages; i++) {
    response.push({
      topic: "broadcast",
      message: JSON.stringify(message)
    });
  }
  return response;
};

When('a mock receive API response is configured to return {int} messages', function(xMessages) {
  const response = xMessageResponse(xMessages);
  this.mockAxios.onGet(
    `${mockValidConfig.api}/receive`, 
  ).reply(200, response);
});

When('a mock receive API response is configured to return an error', function() {
  this.mockAxios.onGet(
    `${mockValidConfig.api}/receive`,
  ).reply(403, { message: 'Token expired' })
});

When('the poll method is called', function() {
  this.call = this.adapter.poll();
});

Then('a successful response is returned with {int} messages', function(xMessages) {
  this.call
  .then(response => {
    assert.equal(response.data.length, xMessages);
  });
});

Then('the protocol {string} method is called {int} times', function(method, xInvokes) {
  const decodes = this.protocol.getTrackedCalls(method);
  assert.equal(decodes.length, xInvokes);
});
